@@ -13,7 +13,7 @@ class Scope(ChainMap):
         # adds all arguments that have not been passed via *args or **kwargs
         # as a keyword argument from Scope
         for arg_name in func_args.args[len(args):]:
-            if not arg_name in call_kwargs:
+            if not arg_name in call_kwargs and arg_name in self:
                 call_kwargs[arg_name] = self[arg_name]
 
         return func(*args, **call_kwargs)
